use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
ABEND
AFAICT
Gratipay
RSRCHBOY
RSRCHBOY's
codebase
coderef
gpg
implementers
ini
metaclass
metaclasses
parameterization
parameterized
subclasses
Formattable
formattable
Chris
Weyl
cweyl
Сергей
Романов
sromanov
lib
autobox
Junctions
